@@ -4,19 +4,19 @@
  *
  * Copyright (C) 2010 - Garrett Regier
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * libpeas is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * libpeas is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -82,10 +82,10 @@ test_plugin_info_verify_full_info (PeasEngine *engine)
   g_assert_cmpstr (peas_plugin_info_get_name (info), ==, "Full Info");
   g_assert_cmpstr (peas_plugin_info_get_description (info), ==, "Has full info.");
   g_assert_cmpstr (peas_plugin_info_get_icon_name (info), ==, "gtk-ok");
-  g_assert_cmpstr (peas_plugin_info_get_website (info), ==, "http://live.gnome.org/Libpeas");
+  g_assert_cmpstr (peas_plugin_info_get_website (info), ==, "https://wiki.gnome.org/Projects/Libpeas");
   g_assert_cmpstr (peas_plugin_info_get_copyright (info), ==, "Copyright © 2010 Garrett Regier");
   g_assert_cmpstr (peas_plugin_info_get_version (info), ==, "1.0");
-  g_assert_cmpstr (peas_plugin_info_get_help_uri (info), ==, "http://git.gnome.org/browse/libpeas");
+  g_assert_cmpstr (peas_plugin_info_get_help_uri (info), ==, "Help Me!");
 
   authors = peas_plugin_info_get_authors (info);
   g_assert (authors != NULL && authors[1] == NULL);
